summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorNorbert Preining <preining@logic.at>2007-06-20 05:26:21 +0000
committerNorbert Preining <preining@logic.at>2007-06-20 05:26:21 +0000
commit4429be21ce9cb6ad65ffe303720a7415f05eec84 (patch)
treec2d096c042e80f96748f12655fc58f1c78a33d04
parent77d0a3f14a12849e35b89e0ea14a497da0fba118 (diff)
tlp replaces
git-svn-id: svn://tug.org/texlive/trunk@4477 c570f23f-e606-0410-a88d-b1316a301751
-rwxr-xr-xMaster/tlpkg/bin/tlpdb2list.pl14
1 files changed, 7 insertions, 7 deletions
diff --git a/Master/tlpkg/bin/tlpdb2list.pl b/Master/tlpkg/bin/tlpdb2list.pl
index e23a8a0d097..7788ecb02f1 100755
--- a/Master/tlpkg/bin/tlpdb2list.pl
+++ b/Master/tlpkg/bin/tlpdb2list.pl
@@ -1,7 +1,7 @@
#!/usr/bin/env perl -w
#
# tldb2list.pl
# create list file from tldb
# Copyright 2007 Norbert Preining
#
# This file is licensed under the GNU General Public Licence version 2
@@ -41,7 +41,7 @@ if (! -d "$opt_outputdir") {
}
-die "Cannot read tldb file $ARGV[0]." if (! -r "$ARGV[0]");
+die "Cannot read tlpdb file $ARGV[0]." if (! -r "$ARGV[0]");
my $tldb = new TeXLive::TLPDB ( location => "$ARGV[0]" );
@@ -51,11 +51,11 @@ __END__
=head1 NAME
-tldb2list - Generates list files from a TeX Live Database
+tlpdb2list - Generates list files from a TeX Live Package Database
=head1 SYNOPSIS
-tldb2list [options] texlive.tldb
+tlpdb2list [options] texlive.tlpdb
Options:
-help brief help message
@@ -87,8 +87,8 @@ Give debug messages from the TeX Live modules
=head1 DESCRIPTION
-B<tldb2list> generates list files necessary for the installer from the
-TeX Live Database.
+B<tlpdb2list> generates list files necessary for the installer from the
+TeX Live Package Database.
=head1 AUTHORS AND COPYRIGHT
@@ -1,7 +1,7 @@
#!/usr/bin/env perl -w
#
-# tldb2list.pl
-# create list file from tldb
+# tlpdb2list.pl
+# create list file from tlpdb
# Copyright 2007 Norbert Preining
#